@@ -97,9 +97,11 @@ if mod_name == "DeepSR": # called as module
 
     import DeepSR.utils as utils
     from DeepSR import LossHistory
+    from DeepSR import epoch_sleep
 else: # called as script
     import utils
     import LossHistory
+    import epoch_sleep
 
 from gc import collect
 
@@ -136,7 +138,6 @@ from keras.backend import image_data_format
 from keras.layers import Activation
 from keras.layers.advanced_activations import LeakyReLU, PReLU
 
-from epoch_sleep import EpochSleep
 
 image_extentions = ["*.bmp", "*.BMP", "*.jpg", "*.JPG", "*.png", "*.PNG", "*.jpeg", "*.JPEG", "*.TIFF", "*.tiff", '*.mat']
 
@@ -1359,7 +1360,7 @@ class DeepSR(object):
         # Sleep after an epoch is finished. Aim of this is to
         # protect GPUs from over heating.
         if hasattr(self, "esleep") and self.esleep > 0:
-            callbacks.append(EpochSleep(self.esleep))
+            callbacks.append(epoch_sleep.EpochSleep(self.esleep))
 
         # append user-defined callbacks
         if hasattr(self, "callbacks"):
